@@ -531,7 +531,9 @@ def dvt_oslog(lockdown: LockdownClient, color, pid):
         with ActivityTraceTap(dvt) as tap:
             for message in tap:
                 message_pid = message.process
-                message_type = message.message_type
+                # without message_type maybe signpost have event_type
+                message_type = message.message_type if hasattr(message, 'message_type') else message.event_type \
+                    if hasattr(message, 'event_type') else "unknown"
                 sender_image_path = message.sender_image_path
                 image_name = os.path.basename(sender_image_path)
                 subsystem = message.subsystem
@@ -541,7 +543,8 @@ def dvt_oslog(lockdown: LockdownClient, color, pid):
                     continue
 
                 try:
-                    formatted_message = decode_message_format(message.message).decode()
+                    formatted_message = decode_message_format(message.message).decode() \
+                        if message.message else message.name
                 except Exception:
                     print('error decoding')
 
@@ -688,7 +691,10 @@ def accessibility_shell(lockdown: LockdownClient):
 def accessibility_notifications(lockdown: LockdownClient, cycle_focus):
     """ show notifications """
 
-    def callback(name, data):
+    service = AccessibilityAudit(lockdown)
+    if cycle_focus:
+        service.move_focus_next()
+    for name, data in service.iter_notifications():
         if name in ('hostAppStateChanged:',
                     'hostInspectorCurrentElementChanged:',):
             for focus_item in data:
@@ -698,11 +704,31 @@ def accessibility_notifications(lockdown: LockdownClient, cycle_focus):
                 if cycle_focus:
                     service.move_focus_next()
 
+
+@accessibility.command('list-items', cls=Command)
+def accessibility_list_items(lockdown: LockdownClient):
+    """ list items available in currently shown menu """
+
     service = AccessibilityAudit(lockdown)
-    service.register_notifications_callback(callback)
-    if cycle_focus:
+    iterator = service.iter_notifications()
+    service.move_focus_next()
+
+    first_item = None
+
+    for name, data in iterator:
+        if name != 'hostInspectorCurrentElementChanged:':
+            continue
+
+        current_item = data[0]
+
+        if first_item is None:
+            first_item = current_item
+        else:
+            if first_item.caption == current_item.caption:
+                return
+
+        print(f'{current_item.caption}: {current_item.element.identifier}')
         service.move_focus_next()
-    service.listen_for_notifications()
 
 
 @developer.group('condition')
